@@ -94,11 +94,12 @@ struct _SpiceChannelClass
     /* virtual methods, coroutine context */
     void (*channel_send_migration_handshake)(SpiceChannel *channel);
 
+    GArray                      *handlers;
     /*
      * If adding fields to this struct, remove corresponding
      * amount of padding to avoid changing overall struct size
      */
-    gchar _spice_reserved[SPICE_RESERVED_PADDING - sizeof(void *)];
+    gchar _spice_reserved[SPICE_RESERVED_PADDING - 2 * sizeof(void *)];
 };
 
 GType spice_channel_get_type(void);
@@ -122,6 +123,8 @@ void spice_channel_set_capability(SpiceChannel *channel, guint32 cap);
 const gchar* spice_channel_type_to_string(gint type);
 gint spice_channel_string_to_type(const gchar *str);
 
+const GError* spice_channel_get_error(SpiceChannel *channel);
+
 G_END_DECLS
 
 #endif /* __SPICE_CLIENT_CHANNEL_H__ */
